###################################################
### chunk number 1: preliminaries
###################################################
library("marelac")
options(prompt = "> ")


###################################################
### chunk number 2: Bath
###################################################
par(mfrow=c(2,1))
par(mar=c(2,2,2,2))
image(Bathymetry$x,Bathymetry$y,Bathymetry$z,col=femmecol(100),
      asp=TRUE,xlab="dg",ylab="dg")
contour(Bathymetry$x,Bathymetry$y,Bathymetry$z,asp=TRUE,add=TRUE)

# remove land and only contours.
zz     <- Bathymetry$z
zz[zz>0]<-0

contour(Bathymetry$x,Bathymetry$y,zz,asp=TRUE)
par(mfrow=c(1,1))
par(mar=c(5.1,4.1,4.1,2.1))


###################################################
### chunk number 3: figbat
###################################################
par(mfrow=c(2,1))
par(mar=c(2,2,2,2))
image(Bathymetry$x,Bathymetry$y,Bathymetry$z,col=femmecol(100),
      asp=TRUE,xlab="dg",ylab="dg")
contour(Bathymetry$x,Bathymetry$y,Bathymetry$z,asp=TRUE,add=TRUE)

# remove land and only contours.
zz     <- Bathymetry$z
zz[zz>0]<-0

contour(Bathymetry$x,Bathymetry$y,zz,asp=TRUE)
par(mfrow=c(1,1))
par(mar=c(5.1,4.1,4.1,2.1))


###################################################
### chunk number 4: SCOC
###################################################
plot(SCOC[,1],SCOC[,2],log="xy",xlab="water depth, m",ylab="" ,
     main="SCOC, mmol O2/m2/d",pch=16,xaxt="n",yaxt="n",cex.main=1)

axis(1,at=c(0.5,5,50,500,5000),labels=c("0.5","5","50","500","5000"))
axis(2,at=c(0.1,1,10,100),labels=c("0.1","1","10","100"))

ll <- lm(log(SCOC[,2])~ log(SCOC[,1]))
rr <- summary(ll)$r.squared
A  <- exp(coef(ll)[1])
B  <- (coef(ll)[2])
curve(A*x^B,add=TRUE,lwd=2)
AA <- round(A*100)/100
BB <- round(B*100)/100
expr <- substitute(y==A*x^B,list(A=AA,B=BB))
text(1,.1,expr,adj=0)
expr2 <- substitute(r^2==rr,list(rr=round(rr*100)/100))
text(1,0.04,expr2, adj=0)


###################################################
### chunk number 5: figscoc
###################################################
plot(SCOC[,1],SCOC[,2],log="xy",xlab="water depth, m",ylab="" ,
     main="SCOC, mmol O2/m2/d",pch=16,xaxt="n",yaxt="n",cex.main=1)

axis(1,at=c(0.5,5,50,500,5000),labels=c("0.5","5","50","500","5000"))
axis(2,at=c(0.1,1,10,100),labels=c("0.1","1","10","100"))

ll <- lm(log(SCOC[,2])~ log(SCOC[,1]))
rr <- summary(ll)$r.squared
A  <- exp(coef(ll)[1])
B  <- (coef(ll)[2])
curve(A*x^B,add=TRUE,lwd=2)
AA <- round(A*100)/100
BB <- round(B*100)/100
expr <- substitute(y==A*x^B,list(A=AA,B=BB))
text(1,.1,expr,adj=0)
expr2 <- substitute(r^2==rr,list(rr=round(rr*100)/100))
text(1,0.04,expr2, adj=0)


###################################################
### chunk number 6: Zoo
###################################################
plot(Zoogrowth$Volume,Zoogrowth$Mumax,log="xy",
      xlab="zooplankton volume, micrometer ^ 3",
      ylab="maximal growth rate, /hr",main="Zoogrowth",cex=2,
      pch=(15:20)[Zoogrowth$Group],col=(1:6)[Zoogrowth$Group])
legend("topright",legend=levels(Zoogrowth$Group),col=1:6,pch=15:20)

ll <- lm(log(Zoogrowth[,2])~ log(Zoogrowth[,1]))
rr <- summary(ll)$r.squared
A  <- exp(coef(ll)[1])
B  <- (coef(ll)[2])
curve(A*x^B,add=TRUE,lwd=2)
AA <- round(A*100)/100
BB <- round(B*100)/100
expr <- substitute(y==A*x^B,list(A=AA,B=BB))
text(100,.0035,expr,adj=0)
expr2 <- substitute(r^2==rr,list(rr=round(rr*100)/100))
text(100,0.002,expr2, adj=0)


###################################################
### chunk number 7: figZoo
###################################################
plot(Zoogrowth$Volume,Zoogrowth$Mumax,log="xy",
      xlab="zooplankton volume, micrometer ^ 3",
      ylab="maximal growth rate, /hr",main="Zoogrowth",cex=2,
      pch=(15:20)[Zoogrowth$Group],col=(1:6)[Zoogrowth$Group])
legend("topright",legend=levels(Zoogrowth$Group),col=1:6,pch=15:20)

ll <- lm(log(Zoogrowth[,2])~ log(Zoogrowth[,1]))
rr <- summary(ll)$r.squared
A  <- exp(coef(ll)[1])
B  <- (coef(ll)[2])
curve(A*x^B,add=TRUE,lwd=2)
AA <- round(A*100)/100
BB <- round(B*100)/100
expr <- substitute(y==A*x^B,list(A=AA,B=BB))
text(100,.0035,expr,adj=0)
expr2 <- substitute(r^2==rr,list(rr=round(rr*100)/100))
text(100,0.002,expr2, adj=0)


###################################################
### chunk number 8: 
###################################################
head(Nemaspec)
# select densities of species present in M160b
st160b<-data.frame(Nemaspec$SPECIES,dens=Nemaspec$M160b)
st160b<-st160b[st160b$dens!=0,]


###################################################
### chunk number 9: Nema
###################################################
plot(cumsum(rev(sort(st160b$dens)/sum(st160b$dens))),main="dominance curve",
     xlab="species rank",ylab="cum freq")


###################################################
### chunk number 10: figNem
###################################################
plot(cumsum(rev(sort(st160b$dens)/sum(st160b$dens))),main="dominance curve",
     xlab="species rank",ylab="cum freq")


###################################################
### chunk number 11: 
###################################################
AtomicWeight
AtomicWeight$H
(W_H2O<- with (AtomicWeight, 2*H + O))


###################################################
### chunk number 12: 
###################################################
data.frame(cbind(acronym=names(Constants),
              matrix(ncol=3,byrow=TRUE,data=unlist(Constants),
              dimnames=list(NULL,c("value","units","description")))))



###################################################
### chunk number 13: cor
###################################################
plot(-90:90,coriolis(-90:90),xlab="latitude, dg North",
                 ylab= "/s" , main ="coriolis factor",type="l",lwd=2)


###################################################
### chunk number 14: figcor
###################################################
plot(-90:90,coriolis(-90:90),xlab="latitude, dg North",
                 ylab= "/s" , main ="coriolis factor",type="l",lwd=2)


###################################################
### chunk number 15: 
###################################################
cp(S=40,T=1:20)


###################################################
### chunk number 16: 
###################################################
diffcoeff(S=15,T=15)*24  # cm2/day
diffcoeff(T=10)$O2
difftemp <- diffcoeff(T=0:30)[,1:13]
diffsal <- diffcoeff(S=0:35)[,1:13]


###################################################
### chunk number 17: diff
###################################################
matplot(0:30,difftemp,xlab="temperature",ylab="cm2/hour",
        main="Molecular/ionic diffusion",type="l")
legend("topleft",ncol=2,cex=0.8,title="mean",col=1:13,lty=1:13,
        legend=cbind(names(difftemp),format(colMeans(difftemp),digits=4)))


###################################################
### chunk number 18: figdif
###################################################
matplot(0:30,difftemp,xlab="temperature",ylab="cm2/hour",
        main="Molecular/ionic diffusion",type="l")
legend("topleft",ncol=2,cex=0.8,title="mean",col=1:13,lty=1:13,
        legend=cbind(names(difftemp),format(colMeans(difftemp),digits=4)))


###################################################
### chunk number 19: visc
###################################################
plot(0:30,viscosity(S=35,T=0:30,P=1),xlab="temperature",ylab="centipoise",
       main="shear viscosity of water",type="l")
  lines(0:30,viscosity(S=0,T=0:30,P=1),col="red")
  lines(0:30,viscosity(S=35,T=0:30,P=100),col="blue")
  legend("topright",col=c("black","red","blue"),lty=1,
        legend=c("S=35,P=1","S=0,P=1","S=35,P=100"))


###################################################
### chunk number 20: figshear
###################################################
plot(0:30,viscosity(S=35,T=0:30,P=1),xlab="temperature",ylab="centipoise",
       main="shear viscosity of water",type="l")
  lines(0:30,viscosity(S=0,T=0:30,P=1),col="red")
  lines(0:30,viscosity(S=35,T=0:30,P=100),col="blue")
  legend("topright",col=c("black","red","blue"),lty=1,
        legend=c("S=35,P=1","S=0,P=1","S=35,P=100"))


###################################################
### chunk number 21: 
###################################################
salconc(S=seq(0,35,by=5))


###################################################
### chunk number 22: 
###################################################
satconc(S=35,T=seq(0,20,by=5))


###################################################
### chunk number 23: 
###################################################
g2mol("CO3")
g2mol("hCO3")
g2mol("H")


###################################################
### chunk number 24: 
###################################################
l2mol(x=8,a=1.382,b=0.03186,T=0)*1000
l2mol(x=1:6)


###################################################
### chunk number 25: 
###################################################
mol.vol()
mol.vol(T=1:10)


###################################################
### chunk number 26: 
###################################################
mol.weight("CO3")
mol.weight("HCO3")
mol.weight("H")


###################################################
### chunk number 27: 
###################################################
sal2cl(S=35)


